pub struct ReviewRequestOptions {
pub reviewers: Vec<String>,
pub team_reviewers: Vec<String>,
}Fields
reviewers: Vec<String>An array of user logins that will be requested.
Note, each login must be a collaborator.
team_reviewers: Vec<String>An array of team slugs that will be requested.