OrgTeamActions

Struct OrgTeamActions 

pub struct OrgTeamActions { /* private fields */ }
reference to teams associated with a github org

Implementations

Source

impl OrgTeamActions

pub fn get(&self) -> Future<Team>

list the team

pub fn update(&self, team_options: &TeamOptions) -> Future<Team>

edit the team

pub fn delete(&self) -> Future<()>

delete the team

pub fn list_members(&self) -> Future<Vec<User>>

list of teams for this org

pub fn iter_members(&self) -> Stream<User>

provides an iterator over all pages of members

pub fn add_user( &self, user: &str, user_options: TeamMemberOptions, ) -> Future<TeamMember>

add a user to the team, if they are already on the team, change the role. If the user is not yet part of the organization, they are invited to join.

pub fn remove_user(&self, user: &str) -> Future<()>

Remove the user from the team