pub struct HookCreateOptionsBuilder(/* private fields */);Implementations
Sourceimpl HookCreateOptionsBuilder
impl HookCreateOptionsBuilder
pub fn active(&mut self, active: bool) -> &mut Self
Sourcepub fn events<E>(&mut self, events: Vec<E>) -> &mut Self
pub fn events<E>(&mut self, events: Vec<E>) -> &mut Self
a list of github events this hook should receive deliveries for the default is “push”. for a full list, see the Github api docs
Sourcepub fn content_type(&mut self, content_type: WebHookContentType) -> &mut Self
pub fn content_type(&mut self, content_type: WebHookContentType) -> &mut Self
web hooks can optionally specify a content_type of “form” or “json” which indicates the type of payload they will expect to receive
Sourcepub fn secret<S>(&mut self, sec: S) -> &mut Self
pub fn secret<S>(&mut self, sec: S) -> &mut Self
web hooks can optionally provide a secret used to sign deliveries to identify that their source was indeed github
pub fn config_str_entry<K, V>(&mut self, k: K, v: V) -> &mut Self
pub fn config_entry<N>(&mut self, name: N, value: Value) -> &mut Self
pub fn build(&self) -> HookCreateOptions