pub struct IssueRef { /* private fields */ }Expand description
Provides access to operations available for a single issue
Typically accessed from github.repo(.., ..).issues().get(number)
Implementations
Sourceimpl IssueRef
impl IssueRef
Sourcepub fn labels(&self) -> IssueLabels
pub fn labels(&self) -> IssueLabels
Return a reference to labels operations available for this issue
Sourcepub fn assignees(&self) -> IssueAssignees
pub fn assignees(&self) -> IssueAssignees
Return a reference to assignee operations available for this issue
Sourcepub fn edit(&self, is: &IssueOptions) -> Future<Issue>
pub fn edit(&self, is: &IssueOptions) -> Future<Issue>
Edit the issues options