pub struct OrgTeamActions { /* private fields */ }Expand description
reference to teams associated with a github org
Implementations
Sourceimpl OrgTeamActions
impl OrgTeamActions
Sourcepub fn update(&self, team_options: &TeamOptions) -> Future<Team>
pub fn update(&self, team_options: &TeamOptions) -> Future<Team>
edit the team
Sourcepub fn list_members(&self) -> Future<Vec<User>>
pub fn list_members(&self) -> Future<Vec<User>>
list of teams for this org
Sourcepub fn iter_members(&self) -> Stream<User>
pub fn iter_members(&self) -> Stream<User>
provides an iterator over all pages of members
Sourcepub fn add_user(
&self,
user: &str,
user_options: TeamMemberOptions,
) -> Future<TeamMember>
pub fn add_user( &self, user: &str, user_options: TeamMemberOptions, ) -> Future<TeamMember>
add a user to the team, if they are already on the team, change the role. If the user is not yet part of the organization, they are invited to join.
Sourcepub fn remove_user(&self, user: &str) -> Future<()>
pub fn remove_user(&self, user: &str) -> Future<()>
Remove the user from the team